@@ -110,6 +110,16 @@ fn_jsonb_array_2_text_array: Final = (
     f" LANGUAGE SQL "
     f" IMMUTABLE;")
 
+fn_jsonb_array_2_uuid_array: Final = (
+    f" CREATE OR REPLACE FUNCTION "
+    f" {CFn.jsonb_array_2_uuid_array} (JSONB) "
+    f" RETURNS UUID[] "
+    f" AS $$ "
+    f"   SELECT array_agg(x)::UUID[] || ARRAY[]::UUID[] FROM {BFn.jsonb_array_elements_text}($1) t(x);"
+    f" $$ "
+    f" LANGUAGE SQL "
+    f" IMMUTABLE;")
+
 fn_jsonb_2_jsonb_array: Final = (
     f" CREATE OR REPLACE FUNCTION "
     f" {CFn.jsonb_2_jsonb_array} (JSONB) "
@@ -172,6 +182,7 @@ def insert_util_fn__json(conn):
     cursor.execute(fn_jsonb_array_2_int_array)
     cursor.execute(fn_jsonb_array_2_smallint_array)
     cursor.execute(fn_jsonb_array_2_text_array)
+    cursor.execute(fn_jsonb_array_2_uuid_array)
     cursor.execute(fn_jsonb_2_jsonb_array)
     cursor.execute(fn_jsonb_remove_key)
     cursor.execute(fn_count_jsonb_keys)
